# Plover {sub-ref}`version` Documentation

[Plover](https://www.openstenoproject.org/plover/) (/ˈplʌvɚ/, rhymes with "lover")
is a free, open source stenography engine. It
allows individuals who learn stenography to write into any program at speeds of
over 200 words per minute. Plover runs on Windows, macOS, and Linux.

Plover is part of the [Open Steno Project](https://www.openstenoproject.org/).
The Open Steno Project aims to
open up stenography to the general public. The Open Steno Project has
manifested as efforts for free software, free learning resources, and open
source hardware options.

## User Guide

```{toctree}
:maxdepth: 2
:caption: User Guide

installation
hardware_setup
basic_usage
dictionaries
plugins
configuration
cli_reference
```

## Developer Guide

```{toctree}
:maxdepth: 2
:caption: Developer Guide

internals
system_dev
plugin_dev
api_reference
contributing
```
